==> lib-ruby-parser-bindings-0.11.0.crate: lib-ruby-parser-bindings-0.11.0/src/api/node.rs <==
use crate::{helpers, options, NS as GLOBAL_NS};
use lib_ruby_parser_nodes::template::*;

const TEMPLATE: &str = "
// Node

// Node constructors
<each-node><dnl>
<helper node-constructor>;
</each-node>

// Node variant predicates
<each-node><dnl>
<helper node-variant-predicate>;
</each-node>

// Node variant getter
<each-node><dnl>
<helper node-variant-getter>;
</each-node>

// Node field getters
<each-node><dnl>
<each-node-field><dnl>
<helper node-field-getter>;
</each-node-field>
</each-node>

// Node field setters
<each-node><dnl>
<each-node-field><dnl>
<helper node-field-setter>;
</each-node-field>
</each-node>

#ifdef __cplusplus
extern \"C\" {
#endif

<each-node><dnl>
<helper internal-struct-definition>
</each-node>

#ifdef __cplusplus
}
#endif

// into_variant fns
<each-node><dnl>
<helper into-variant>;
</each-node>

// into_internal fns
<each-node><dnl>
<helper into-internal>;
</each-node>

// variant drop fns
<each-node><dnl>
<helper drop-variant>;
</each-node>

void <helper fn-attributes> <helper ns>__node__drop(<helper node-blob>* self_blob);
";

pub fn node() -> String {
    let template = TemplateRoot::new(TEMPLATE).unwrap();
    let mut fns = TemplateFns::new();
    fns.register_helper("node-constructor", helpers::nodes::constructor::sig);
    fns.register_helper(
        "node-variant-predicate",
        helpers::nodes::variant_predicate::sig,
    );
    fns.register_helper("node-variant-getter", helpers::nodes::variant_getter::sig);
    fns.register_helper("node-field-getter", helpers::nodes::field_getter::sig);
    fns.register_helper("node-field-setter", helpers::nodes::field_setter::sig);
    fns.register_helper(
        "internal-struct-definition",
        helpers::nodes::internal_struct::definition,
    );
    fns.register_helper("into-variant", helpers::nodes::into_variant::sig);
    fns.register_helper("into-internal", helpers::nodes::into_internal::sig);
    fns.register_helper("drop-variant", helpers::nodes::drop_variant::sig);

    fn fn_attributes(_: &GlobalContext) -> String {
        options().fn_attributes.to_string()
    }
    fns.register_helper("fn-attributes", fn_attributes);

    fn ns(_: &GlobalContext) -> String {
        GLOBAL_NS.to_string()
    }
    fns.register_helper("ns", ns);

    fn node_blob(_: &GlobalContext) -> String {
        options().node_blob_name.to_string()
    }
    fns.register_helper("node-blob", node_blob);

    template.render(ALL_DATA, &fns)
}

==> lib-ruby-parser-bindings-0.12.0.crate: lib-ruby-parser-bindings-0.12.0/src/api/node.rs <==
use crate::{helpers, options, NS as GLOBAL_NS};
use lib_ruby_parser_nodes::template::*;

const TEMPLATE: &str = "
// Node

// Node constructors
{{ each node }}<dnl>
{{ helper node-constructor }};
{{ end }}

// Node variant predicates
{{ each node }}<dnl>
{{ helper node-variant-predicate }};
{{ end }}

// Node variant getter
{{ each node }}<dnl>
{{ helper node-variant-getter }};
{{ end }}

// Node field getters
{{ each node }}<dnl>
{{ each node-field }}<dnl>
{{ helper node-field-getter }};
{{ end }}
{{ end }}

// Node field setters
{{ each node }}<dnl>
{{ each node-field }}<dnl>
{{ helper node-field-setter }};
{{ end }}
{{ end }}

#ifdef __cplusplus
extern \"C\" {
#endif

{{ each node }}<dnl>
{{ helper internal-struct-definition }}
{{ end }}

#ifdef __cplusplus
}
#endif

// into_variant fns
{{ each node }}<dnl>
{{ helper into-variant }};
{{ end }}

// into_internal fns
{{ each node }}<dnl>
{{ helper into-internal }};
{{ end }}

// variant drop fns
{{ each node }}<dnl>
{{ helper drop-variant }};
{{ end }}

void {{ helper fn-attributes }} {{ helper ns }}__node__drop({{ helper node-blob }}* self_blob);
";

pub fn node() -> String {
    let template = TemplateRoot::new(TEMPLATE).unwrap();
    let mut fns = TemplateFns::new();
    fns.register_helper("node-constructor", helpers::nodes::constructor::sig);
    fns.register_helper(
        "node-variant-predicate",
        helpers::nodes::variant_predicate::sig,
    );
    fns.register_helper("node-variant-getter", helpers::nodes::variant_getter::sig);
    fns.register_helper("node-field-getter", helpers::nodes::field_getter::sig);
    fns.register_helper("node-field-setter", helpers::nodes::field_setter::sig);
    fns.register_helper(
        "internal-struct-definition",
        helpers::nodes::internal_struct::definition,
    );
    fns.register_helper("into-variant", helpers::nodes::into_variant::sig);
    fns.register_helper("into-internal", helpers::nodes::into_internal::sig);
    fns.register_helper("drop-variant", helpers::nodes::drop_variant::sig);

    fn fn_attributes(_: &GlobalContext) -> String {
        options().fn_attributes.to_string()
    }
    fns.register_helper("fn-attributes", fn_attributes);

    fn ns(_: &GlobalContext) -> String {
        GLOBAL_NS.to_string()
    }
    fns.register_helper("ns", ns);

    fn node_blob(_: &GlobalContext) -> String {
        options().node_blob_name.to_string()
    }
    fns.register_helper("node-blob", node_blob);

    template.render(ALL_DATA, &fns)
}
